import { Injectable, NotFoundException } from '@nestjs/common';
import { Repository } from 'typeorm';
import { User } from './entities/user.entity';
import { CreateUserDto } from './dto/create-user.dto';
import { UpdateUserDto } from './dto/update-user.dto';

@Injectable()
export class UserService {
  private readonly userRepository: Repository<User>;
  async create(createUserDto: CreateUserDto): Promise<User> {
    const newUser = await this.userRepository.create(createUserDto);
    await this.userRepository.save(newUser);
    return newUser;
  }

  findAll() {
    return this.userRepository.find();
  }

  async findOne(id: number) {
    const userInfo = await this.userRepository.findOne({
      where: { id },
    });
    return userInfo;
  }

  async update(id: number, updateUserDto: UpdateUserDto) {
    const oldData = await this.userRepository.findOne({
      where: {
        id,
      },
    });
    return this.userRepository.merge(oldData, updateUserDto);
  }

  async remove(id: number) {
    const result = await this.userRepository.delete(id);
    if (result.affected === 0) {
      throw new NotFoundException(`User with ID ${id} not found`);
    }
  }
}
